pub struct OverlapAddConvolver<T: Transcendental, const BUF_SIZE: usize> { /* private fields */ }Expand description
Overlap-add frequency-domain convolver.
Uses a real FFT for efficient frequency-domain multiplication. All scratch buffers are pre-allocated at construction time.
Parameters
T— sample type (f32orf64)BUF_SIZE— processing block size in samples
Implementations
Sourceimpl<T: Transcendental, const BUF_SIZE: usize> OverlapAddConvolver<T, BUF_SIZE>
impl<T: Transcendental, const BUF_SIZE: usize> OverlapAddConvolver<T, BUF_SIZE>
Sourcepub fn new(ir_len: usize) -> Self
pub fn new(ir_len: usize) -> Self
Create a new overlap-add convolver.
ir_len is the expected length of the impulse response. The FFT size
is chosen as the next power of two >= BUF_SIZE + ir_len - 1.
Panics
Panics if the resulting FFT size is less than 4.