pub struct RealFft<T: Transcendental> { /* private fields */ }Expand description
Real-valued FFT.
Uses a half-size complex FFT internally via the two-for-one method.
Transforms N real samples into N/2 + 1 complex bins (only the
non-redundant half of the spectrum). The Nyquist bin (N/2) and
DC bin (0) are purely real.
Panics
Panics if size is not a power of two or less than 4.
Implementations
Sourceimpl<T: Transcendental> RealFft<T>
impl<T: Transcendental> RealFft<T>
Sourcepub fn new(size: usize) -> Self
pub fn new(size: usize) -> Self
Create a new real FFT for the given size.
Panics
Panics if size is not a power of two or is less than 4.